#ifndef  PP_PHY_H
#define  PP_PHY_H
//=============================================================================
// ppPhy.h
//-----------------------------------------------------------------------------
// Copyright 2010 Silicon Laboratories, Inc.
// http://www.silabs.com
//
// Header File Description:
//
// Target:
//    Si10xx.
//
// IDE:
//    Silicon Laboratories IDE
//
// Tool Chains:
//    Keil
//    SDCC
//    Raisonance
//
// Project Name:
//    PreProcessorPHY
//
// Release 1.1
//    - TBD
//
// This software must be used in accordance with the End User License Agreement.
//
//=============================================================================
#ifndef COMPILER_DEFS_H
#include <si_toolchain.h>
#endif
#ifndef PHY_DEFS_H
#include "ppPhy_defs.h"
#endif
//-----------------------------------------------------------------------------
// Expected RADIO_VERSION code for radio VERSION register
// Production version should be 0x06
//-----------------------------------------------------------------------------
#define MIN_RADIO_VERSION   0x05
//-----------------------------------------------------------------------------
//
//-----------------------------------------------------------------------------
#define SYSCLK_HZ                (24500000L)
#define MILLISECONDS(t)          (((SYSCLK_HZ/1000)*(t))/48)
//-----------------------------------------------------------------------------
// ET0 inverted and used as timeout flag
//-----------------------------------------------------------------------------
#define TIMEOUT_T0   (!ET0)
//-----------------------------------------------------------------------------
// phy status values
//-----------------------------------------------------------------------------
#define PHY_STATUS uint8_t
enum
{
   PHY_STATUS_SUCCESS = 0x00,
   PHY_STATUS_ERROR_SPI,
   PHY_STATUS_ERROR_UNSUPPORTED_RADIO,
   PHY_STATUS_ERROR_NO_IRQ,
   PHY_STATUS_ERROR_RADIO_XTAL,
   PHY_STATUS_ERROR_RADIO_SHUTDOWN,
   PHY_STATUS_TRANSMIT_ERROR,
   PHY_STATUS_ERROR_NO_PACKET
};
//-----------------------------------------------------------------------------
// Public variables (API)
//-----------------------------------------------------------------------------
extern bit RxPacketReceived;
extern SI_SEGMENT_VARIABLE(RxPacketLength, uint8_t, BUFFER_MSPACE);
extern SI_SEGMENT_VARIABLE(RxErrors, uint8_t, BUFFER_MSPACE);
//-----------------------------------------------------------------------------
// Public function prototypes (API)
//-----------------------------------------------------------------------------
PHY_STATUS  ppPhyInit (void);
PHY_STATUS  ppPhyInitRadio (void);
PHY_STATUS  ppPhyStandby (void);
PHY_STATUS  ppPhyIdle (void);
PHY_STATUS  ppPhyShutDown (void);
PHY_STATUS  ppPhyReStart (void);
PHY_STATUS  ppPhyTx (uint8_t, SI_VARIABLE_SEGMENT_POINTER(txBuffer, uint8_t, BUFFER_MSPACE));
PHY_STATUS  ppPhyRxOn (void);
PHY_STATUS  ppPhyRxOff (void);
PHY_STATUS  ppPhyGetRxPacket (uint8_t*, SI_VARIABLE_SEGMENT_POINTER(rxBuffer, uint8_t, BUFFER_MSPACE));
//-----------------------------------------------------------------------------
// Phy primitive readn and write - use with caution
//-----------------------------------------------------------------------------
void  phyWrite (uint8_t, uint8_t);
uint8_t    phyRead (uint8_t);
void  phyWriteFIFO (uint8_t, SI_VARIABLE_SEGMENT_POINTER(buffer, uint8_t, BUFFER_MSPACE));
void  phyReadFIFO (uint8_t, SI_VARIABLE_SEGMENT_POINTER(buffer, uint8_t, BUFFER_MSPACE));
//=============================================================================
// end PP_PHY_H
//=============================================================================
#endif //PP_PHY_H