//=============================================================================
// ppPhy_const.c
//=============================================================================
// Copyright 2010 Silicon Laboratories, Inc.
// http://www.silabs.com
//
// C File Description:
//
// Target:
//    Si10xx
//
// IDE:
//    Silicon Laboratories IDE
//
// Tool Chains:
//    Keil
//    SDCC
//    Raisonance
//
// Project Name:
//    PreProcessorPHY
//
// Release 1.1
//    - TBD
//
// This software must be used in accordance with the End User License Agreement.
//
//=============================================================================
//-----------------------------------------------------------------------------
// Use #pragma SRC to check PHY settings against Excel calculator
//-----------------------------------------------------------------------------
//#pragma SRC
//-----------------------------------------------------------------------------
// Includes
//
// These includes must be in a specific order. Dependencies listed in comments.
//-----------------------------------------------------------------------------
#include <si_toolchain.h>
#include "ppPhy_defs.h"
#include "ppPhy_const.h"
#include "hardware_defs.h"
//-----------------------------------------------------------------------------
// RX_BAND_WIDTH must be defined before including this file
//-----------------------------------------------------------------------------
#include "ppPhyIfFilterBandwidth.h"
//-----------------------------------------------------------------------------
// Frequency and Data rate settings
//-----------------------------------------------------------------------------
#define DEFAULT_MODULATION_MODE_CONTROL_1    0x0C  // Manchester disabled
#define DEFAULT_MODULATION_MODE_CONTROL_2    0x23  // FIFO mode GFSK
#define DEFAULT_AFC_LOOP_GEARSHIFT_OVERRIDE  0x40  // AFC Enabled setting
#define DEFAULT_TX_POWER                     0x1F  // +20 dB, LNA switch enabled
//-----------------------------------------------------------------------------
// Phy Radio Register to be set
//-----------------------------------------------------------------------------
const SI_SEGMENT_VARIABLE(ppPhyRegisters[NUMBER_OF_REGISTERS], uint8_t, code) =
{
   EZRADIOPRO_DATA_ACCESS_CONTROL,                                          // 0x30
   EZRADIOPRO_HEADER_CONTROL_1,                                             // 0x32
   EZRADIOPRO_HEADER_CONTROL_2,                                             // 0x33
   EZRADIOPRO_PREAMBLE_LENGTH,                                              // 0x34
   EZRADIOPRO_PREAMBLE_DETECTION_CONTROL,                                   // 0x35

   EZRADIOPRO_MODULATION_MODE_CONTROL_1,                                    // 0x70
   EZRADIOPRO_MODULATION_MODE_CONTROL_2,                                    // 0x71

  //TRX Frequency Registers
   EZRADIOPRO_FREQUENCY_BAND_SELECT,                                        // 0x75
   EZRADIOPRO_NOMINAL_CARRIER_FREQUENCY_1,                                  // 0x76
   EZRADIOPRO_NOMINAL_CARRIER_FREQUENCY_0,                                  // 0x77
   EZRADIOPRO_FREQUENCY_HOPPING_STEP_SIZE,                                  // 0x7A


#ifndef RECEIVER_ONLY
   //TX Modem Registers
   EZRADIOPRO_TX_POWER,                                                     // 0x6D
   EZRADIOPRO_TX_DATA_RATE_1,                                               // 0x6E
   EZRADIOPRO_TX_DATA_RATE_0,                                               // 0x6F
   EZRADIOPRO_FREQUENCY_DEVIATION,                                          // 0x72
#endif
#ifndef TRANSMITTER_ONLY
    // RX Modem Registers
   EZRADIOPRO_IF_FILTER_BANDWIDTH,                                          // 0x1C
   EZRADIOPRO_AFC_LOOP_GEARSHIFT_OVERRIDE,                                  // 0x1D
   EZRADIOPRO_CLOCK_RECOVERY_OVERSAMPLING_RATIO,                            // 0x20
   EZRADIOPRO_CLOCK_RECOVERY_OFFSET_2,                                      // 0x21
   EZRADIOPRO_CLOCK_RECOVERY_OFFSET_1,                                      // 0x22
   EZRADIOPRO_CLOCK_RECOVERY_OFFSET_0,                                      // 0x23
   EZRADIOPRO_CLOCK_RECOVERY_TIMING_LOOP_GAIN_1,                            // 0x24
   EZRADIOPRO_CLOCK_RECOVERY_TIMING_LOOP_GAIN_0,                            // 0x25
   EZRADIOPRO_AFC_LIMITER,                                                  // 0x2A
#endif
};
//--------------------------------------------------------------------------------
// Preprocessor Calculated Constant Radio Settings
//--------------------------------------------------------------------------------
const SI_SEGMENT_VARIABLE(ppPhySettings[NUMBER_OF_REGISTERS], uint8_t, code) =
{
   0x8D, // 0x30 - SI4432_DATA_ACCESS_CONTROL - enable TX & RX packet handler, enable CRC
   0x00, // 0x32 - SI4432_HEADER_CONTROL_1 - no header
   0x02, // 0x33 - SI4432_HEADER_CONTROL_2 - 2 byte sync word, variable packet length
   0x0A, // 0x34 - SI4432_PREAMBLE_LENGTH - 10 nibbles, 40 bits
   0x28, // 0x35 - SI4432_PREAMBLE_DETECTION_CONTROL -  5 nibbles, 20 bits

#ifdef RECEIVER_ONLY
   // use default settings for Modulation control
   (DEFAULT_MODULATION_MODE_CONTROL_1),                                 // 0x70
   (DEFAULT_MODULATION_MODE_CONTROL_2),                                 // 0x71
#else
   // include transmitter modem settings in Modulation control
   (DEFAULT_MODULATION_MODE_CONTROL_1|TX_DATA_RATE_LOW(TRX_DATA_RATE)),  // 0x70
   (DEFAULT_MODULATION_MODE_CONTROL_2|TX_DEVIATION_B8(TRX_DEVIATION)),   // 0x71
#endif

   //TX Frequency Settings
   CALC_FREQUENCY_BAND_SELECT(TRX_FREQUENCY),                           // 0x75
   CALC_NOMINAL_CARRIER_FREQUENCY_1(TRX_FREQUENCY),                     // 0x76
   CALC_NOMINAL_CARRIER_FREQUENCY_0(TRX_FREQUENCY),                     // 0x77
   CALC_FREQUENCY_HOPPING_STEP_SIZE(TRX_CHANNEL_SPACING),               // 0x7A

#ifndef RECEIVER_ONLY
  //TX Modem Settings
   DEFAULT_TX_POWER,                                                     // 0x6D
   CALC_TX_DATA_RATE_1(TRX_DATA_RATE),                                   // 0x6E
   CALC_TX_DATA_RATE_0(TRX_DATA_RATE),                                   // 0x6F
   CALC_TX_DEVIATION(TRX_DEVIATION),                                     // 0x72
#endif

#ifndef TRANSMITTER_ONLY
    // RX Modem Settings
   IF_FILTER_BANDWIDTH,                                                 // 0x1C
   DEFAULT_AFC_LOOP_GEARSHIFT_OVERRIDE,                                 // 0x1D
   CALC_CLOCK_RECOVERY_OVERSAMPLING_RATIO(RX_DWN3_BYP,RX_NDEC_EXP,TRX_DATA_RATE),// 0x20
   CALC_CLOCK_RECOVERY_OFFSET_2(RX_DWN3_BYP,RX_NDEC_EXP,TRX_DATA_RATE), // 0x21
   CALC_CLOCK_RECOVERY_OFFSET_1(RX_DWN3_BYP,RX_NDEC_EXP,TRX_DATA_RATE), // 0x22
   CALC_CLOCK_RECOVERY_OFFSET_0(RX_DWN3_BYP,RX_NDEC_EXP,TRX_DATA_RATE), // 0x23
   CALC_CLOCK_RECOVERY_TIMING_LOOP_GAIN_1(TRX_DATA_RATE,RX_DWN3_BYP,RX_NDEC_EXP,TRX_DEVIATION),// 0x24
   CALC_CLOCK_RECOVERY_TIMING_LOOP_GAIN_0(TRX_DATA_RATE,RX_DWN3_BYP,RX_NDEC_EXP,TRX_DEVIATION),// 0x25
   AFC_LIMIT                                                            // 0x2A
#endif
};
//==============================================================================
// End
//==============================================================================

