#ifndef  PP_PHY_CONST_H
#define  PP_PHY_CONST_H
//================================================================================================
// ppPhyConst.h
//------------------------------------------------------------------------------------------------
// Copyright 2009 Silicon Laboratories, Inc.
// http://www.silabs.com
//
// Header File Description:
//
// Target:
//    Si10xx
//
// IDE:
//    Silicon Laboratories IDE
//
// Tool Chains:
//    Keil
//    SDCC
//    Raisonance
//
// Project Name:
//    PreProcessorPHY
//
// Release 1.1
//    - TBD
//
// This software must be used in accordance with the End User License Agreement.
//
//================================================================================================
#ifndef COMPILER_DEFS_H
#include <si_toolchain.h>
#endif
//------------------------------------------------------------------------------------------------
// defines
//------------------------------------------------------------------------------------------------
//------------------------------------------------------------------------------------------------
// defines
//------------------------------------------------------------------------------------------------
#define DIVR(a,b)    ((a+b/2)/b)
#define BYTE0(a)     (a&0x000000FFL)
#define BYTE1(a)     ((a&0x0000FF00L)>>8)
#define BYTE2(a)     ((a&0x00FF0000L)>>16)
#define BYTE3(a)     ((a&0xFF000000L)>>24)
//------------------------------------------------------------------------------------------------
// Frequency Macros
//------------------------------------------------------------------------------------------------
#define CALC_HIGH_FREQ_BAND(f)               ((f-480000000L)/20000000L)
#define CALC_LOW_FREQ_BAND(f)                ((f-240000000L)/10000000L)
#define CALC_FREQUENCY_BAND_SELECT(f)        ((f>480000000)?(CALC_HIGH_FREQ_BAND(f)|0x60):(CALC_LOW_FREQ_BAND(f)|0x40))
#define CALC_CARRIER_FREQUENCY_HIGH(f)       ((DIVR((f-480000000L-20000000L*CALC_HIGH_FREQ_BAND(f)),625L))<<1)
#define CALC_CARRIER_FREQUENCY_LOW(f)        ((DIVR((f-240000000L-10000000L*CALC_LOW_FREQ_BAND(f)),625L))<<2)
#define CALC_NOMINAL_CARRIER_FREQEUNCY(f)    ((f>480000000)?CALC_CARRIER_FREQUENCY_HIGH(f):CALC_CARRIER_FREQUENCY_LOW(f))
#define CALC_NOMINAL_CARRIER_FREQUENCY_0(f)  BYTE0(CALC_NOMINAL_CARRIER_FREQEUNCY(f))
#define CALC_NOMINAL_CARRIER_FREQUENCY_1(f)  BYTE1(CALC_NOMINAL_CARRIER_FREQEUNCY(f))
//------------------------------------------------------------------------------------------------
// TRX_CHANNEL_SPACING Macros
//------------------------------------------------------------------------------------------------
#define CALC_FREQUENCY_HOPPING_STEP_SIZE(f)  (DIVR(f,10000L))
//------------------------------------------------------------------------------------------------
// TX_DEVIATION Macros
//------------------------------------------------------------------------------------------------
#define CALC_TX_DEVIATION(f)  (DIVR(f,625L))
#define TX_DEVIATION_B8(f)      ((DIVR(f,625L)>255)?0x40:0x00)
//------------------------------------------------------------------------------------------------
// TX_DATA_RATE Macros
//------------------------------------------------------------------------------------------------
#define TX_DATA_RATE_LOW(r)         ((r<30000L)?0x20:0x00)
#define CALC_TX_DATA_RATE_LOW(r)    (DIVR((r<<16),31250L))
#define CALC_TX_DATA_RATE_HIGH(r)   (DIVR((r<<15),500000L))
#define CALC_TX_DATA_RATE(r)        ((r<30000L)?CALC_TX_DATA_RATE_LOW(r):CALC_TX_DATA_RATE_HIGH(r))
#define CALC_TX_DATA_RATE_0(r)      BYTE0(CALC_TX_DATA_RATE(r))
#define CALC_TX_DATA_RATE_1(r)      BYTE1(CALC_TX_DATA_RATE(r))
//------------------------------------------------------------------------------------------------
// RX Modem Macros
//------------------------------------------------------------------------------------------------
#define CALC_RXOSR(dwn3_bypass,ndec_exp,rb)   (DIVR(((500000L*8*(dwn3_bypass*2+1))>>ndec_exp),(rb)))

#define CALC_NCOFF(dwn3_bypass,ndec_exp,rb)  (DIVR(((DIVR(((rb)<<15),15625))<<ndec_exp),(dwn3_bypass*2+1)))

#define CALC_CRGAIN(rb,dwn3_bypass,ndec_exp,rxdev) (DIVR(DIVR((rb<<15),(DIVR(((500000L*8*(dwn3_bypass*2+1))>>ndec_exp),(rb)))),rxdev)+2)

//------------------------------------------------------------------------------------------------
// RX Modem Register Macros
//------------------------------------------------------------------------------------------------
#define CALC_IF_FILTER_BANDWIDTH(dwn3_bypass,ndec_exp,filset) (((dwn3_bypass)<<7)+((ndec_exp)<<4)+(filset))
#define CALC_CLOCK_RECOVERY_OVERSAMPLING_RATIO(dwn3_bypass,ndec_exp,rb)  BYTE0(CALC_RXOSR(dwn3_bypass,ndec_exp,rb))
#define CALC_CLOCK_RECOVERY_OFFSET_2(dwn3_bypass,ndec_exp,rb)    BYTE2(CALC_NCOFF(dwn3_bypass,ndec_exp,rb))
#define CALC_CLOCK_RECOVERY_OFFSET_1(dwn3_bypass,ndec_exp,rb)    BYTE1(CALC_NCOFF(dwn3_bypass,ndec_exp,rb))
#define CALC_CLOCK_RECOVERY_OFFSET_0(dwn3_bypass,ndec_exp,rb)    BYTE0(CALC_NCOFF(dwn3_bypass,ndec_exp,rb))
#define CALC_CLOCK_RECOVERY_TIMING_LOOP_GAIN_1(rb,dwn3_bypass,ndec_exp,rxdev)    BYTE1( CALC_CRGAIN(rb,dwn3_bypass,ndec_exp,rxdev))
#define CALC_CLOCK_RECOVERY_TIMING_LOOP_GAIN_0(rb,dwn3_bypass,ndec_exp,rxdev)    BYTE0( CALC_CRGAIN(rb,dwn3_bypass,ndec_exp,rxdev))
#define CALC_AFC_LIMITER(afcrange, f)   ((f>480000000)?(DIVR((afcrange/2),625)):(DIVR(afcrange,625)))
//------------------------------------------------------------------------------------------------
// defines
//------------------------------------------------------------------------------------------------
#ifdef TRANSMITTER_ONLY
#define NUMBER_OF_REGISTERS                       15
#endif
#ifdef  RECEIVER_ONLY
#define NUMBER_OF_REGISTERS                       20
#endif
#ifndef NUMBER_OF_REGISTERS
#define NUMBER_OF_REGISTERS                       24
#endif
//------------------------------------------------------------------------------------------------
// Public code constants
//------------------------------------------------------------------------------------------------
extern SI_SEGMENT_VARIABLE(ppPhyRegisters[NUMBER_OF_REGISTERS], uint8_t, code);
extern SI_SEGMENT_VARIABLE(ppPhySettings[NUMBER_OF_REGISTERS], uint8_t, code);
//=================================================================================================
//=================================================================================================
#endif //PP_PHY_CONST_H