#ifndef  RT_PHY_H
#define  RT_PHY_H
//================================================================================================
// Phy.h
//------------------------------------------------------------------------------------------------
// Copyright 2009 Silicon Laboratories, Inc.
// http://www.silabs.com
//
// Header File Description:
//
// Target:
//    Any Silicon Labs C8051 MCU.
//
// IDE:
//    Silicon Laboratories IDE   version 3.3
//
// Tool Chains:
//    Keil
//       c51.exe     version 8.0.8
//       bl51.exe    version 6.0.5
//    SDCC
//       sdcc.exe    version 2.8.0
//       aslink.exe  version 1.75
//
// Project Name:
//    MCM Code Examples
//
// Beta Release 0.9
//    - TBD
//
// This software must be used in accordance with the End User License Agreement.
//
//================================================================================================
#ifndef COMPILER_DEFS_H
#include <si_toolchain.h>
#endif
#ifndef PHY_DEFS_H
#include "rtPhy_defs.h"
#endif
//-----------------------------------------------------------------------------
// Expected RADIO_VERSION code for radio VERSION register
// Production version should be 0x06
//-----------------------------------------------------------------------------
#define MIN_RADIO_VERSION   0x05
//------------------------------------------------------------------------------------------------
//
//------------------------------------------------------------------------------------------------
#define SYSCLK_HZ                (24500000L)
#define MILLISECONDS(t)          (((SYSCLK_HZ/1000)*(t))/48)
//-----------------------------------------------------------------------------
// ET0 inverted and used as timeout flag
//-----------------------------------------------------------------------------
#define TIMEOUT_T0   (!ET0)
//------------------------------------------------------------------------------------------------
// PHY Variables accessed using phySet()/phyget()
//------------------------------------------------------------------------------------------------
enum
{
 TRX_FREQUENCY = 0,
 TRX_CHANNEL_SPACING,
 TRX_DEVIATION,
 TRX_DATA_RATE,
 RX_BAND_WIDTH
};
//------------------------------------------------------------------------------------------------
// phy data structure typedef - must match enum above
//------------------------------------------------------------------------------------------------
typedef struct rtPhySettingsStruct
{
 uint32_t TRxFrequency;
 uint32_t TRxChannelSpacing;
 uint32_t TRxDeviation;
 uint32_t TRxDataRate;
 uint32_t RxBandWidth;
} rtPhySettingsStruct;
//------------------------------------------------------------------------------------------------
// phy status values
//------------------------------------------------------------------------------------------------
#define PHY_STATUS uint8_t
enum
{
   PHY_STATUS_SUCCESS = 0x00,
   PHY_STATUS_ERROR_SPI,
   PHY_STATUS_ERROR_UNSUPPORTED_RADIO,
   PHY_STATUS_ERROR_NO_IRQ,
   PHY_STATUS_ERROR_RADIO_XTAL,
   PHY_STATUS_ERROR_RADIO_SHUTDOWN,
   PHY_STATUS_ERROR_READ_ONLY_ADDRESS,
   PHY_STATUS_ERROR_INVALID_ADDRESS,
   PHY_STATUS_ERROR_INVALID_VALUE,
   PHY_STATUS_TRANSMIT_ERROR,
   PHY_STATUS_ERROR_NO_PACKET
};
//------------------------------------------------------------------------------------------------
// Public variables (API)
//------------------------------------------------------------------------------------------------
extern bit RxPacketReceived;
extern SI_SEGMENT_VARIABLE(RxPacketLength, uint8_t, BUFFER_MSPACE);
extern SI_SEGMENT_VARIABLE(RxErrors, uint8_t, BUFFER_MSPACE);
//------------------------------------------------------------------------------------------------
// Public Run Time PHY function prototypes (API)
//------------------------------------------------------------------------------------------------
PHY_STATUS    rtPhyInit (void);          // called once after MCU reset
PHY_STATUS    rtPhySet (uint8_t, uint32_t);
PHY_STATUS    rtPhyGet (uint32_t *);
PHY_STATUS    rtPhyInitRadio (void);
PHY_STATUS    rtPhyStandby (void);
PHY_STATUS    rtPhyIdle (void);
PHY_STATUS    rtPhyShutDown (void);
PHY_STATUS    rtPhyReStart (void);
PHY_STATUS    rtPhyTx (uint8_t, SI_VARIABLE_SEGMENT_POINTER(buffer, uint8_t, BUFFER_MSPACE));
PHY_STATUS    rtPhyRxOn (void);
PHY_STATUS    rtPhyRxOff (void);
PHY_STATUS    rtPhyGetRxPacket (uint8_t*, SI_VARIABLE_SEGMENT_POINTER(buffer, uint8_t, BUFFER_MSPACE));
//------------------------------------------------------------------------------------------------
// Public primitive phy function prototypes
//------------------------------------------------------------------------------------------------
void  phyWrite (uint8_t, uint8_t);
uint8_t    phyRead (uint8_t);
void  phyWriteFIFO (uint8_t, SI_VARIABLE_SEGMENT_POINTER(buffer, uint8_t, BUFFER_MSPACE));
//=================================================================================================
//=================================================================================================
#endif //RT_PHY_H